from . import ucsbutilities

def clear_data_mask(data_container_array, mask_array_path = None, observer = None) -> int:
  """
  ClearDataMask

  :param data_container_array | DataContainerArray
  :param mask_array_path | DataArrayPath MaskArrayPath
  :param observer | Observer
  """

  filter = ucsbutilities.ClearDataMask()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if mask_array_path is not None:
    filter.MaskArrayPath = mask_array_path
  filter.execute()
  return filter.ErrorCode

def copy_attribute_array(data_container_array, selected_array_path = None, new_array_name = None, observer = None) -> int:
  """
  CopyAttributeArray

  :param data_container_array | DataContainerArray
  :param selected_array_path | DataArrayPath SelectedArrayPath
  :param new_array_name | QString NewArrayName
  :param observer | Observer
  """

  filter = ucsbutilities.CopyAttributeArray()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if selected_array_path is not None:
    filter.SelectedArrayPath = selected_array_path
  if new_array_name is not None:
    filter.NewArrayName = new_array_name
  filter.execute()
  return filter.ErrorCode

def copy_attribute_matrix(data_container_array, selected_attribute_matrix_path = None, new_attribute_matrix = None, observer = None) -> int:
  """
  CopyAttributeMatrix

  :param data_container_array | DataContainerArray
  :param selected_attribute_matrix_path | DataArrayPath SelectedAttributeMatrixPath
  :param new_attribute_matrix | QString NewAttributeMatrix
  :param observer | Observer
  """

  filter = ucsbutilities.CopyAttributeMatrix()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if selected_attribute_matrix_path is not None:
    filter.SelectedAttributeMatrixPath = selected_attribute_matrix_path
  if new_attribute_matrix is not None:
    filter.NewAttributeMatrix = new_attribute_matrix
  filter.execute()
  return filter.ErrorCode

def copy_data_container(data_container_array, selected_data_container_name = None, new_data_container_name = None, observer = None) -> int:
  """
  CopyDataContainer

  :param data_container_array | DataContainerArray
  :param selected_data_container_name | DataArrayPath SelectedDataContainerName
  :param new_data_container_name | DataArrayPath NewDataContainerName
  :param observer | Observer
  """

  filter = ucsbutilities.CopyDataContainer()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if selected_data_container_name is not None:
    filter.SelectedDataContainerName = selected_data_container_name
  if new_data_container_name is not None:
    filter.NewDataContainerName = new_data_container_name
  filter.execute()
  return filter.ErrorCode

def find_boundary_areas(data_container_array, surface_mesh_triangle_areas_array_path = None, surface_mesh_feature_face_ids_array_path = None, surface_mesh_boundary_areas_array_path = None, observer = None) -> int:
  """
  FindBoundaryAreas

  :param data_container_array | DataContainerArray
  :param surface_mesh_triangle_areas_array_path | DataArrayPath SurfaceMeshTriangleAreasArrayPath
  :param surface_mesh_feature_face_ids_array_path | DataArrayPath SurfaceMeshFeatureFaceIdsArrayPath
  :param surface_mesh_boundary_areas_array_path | DataArrayPath SurfaceMeshBoundaryAreasArrayPath
  :param observer | Observer
  """

  filter = ucsbutilities.FindBoundaryAreas()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if surface_mesh_triangle_areas_array_path is not None:
    filter.SurfaceMeshTriangleAreasArrayPath = surface_mesh_triangle_areas_array_path
  if surface_mesh_feature_face_ids_array_path is not None:
    filter.SurfaceMeshFeatureFaceIdsArrayPath = surface_mesh_feature_face_ids_array_path
  if surface_mesh_boundary_areas_array_path is not None:
    filter.SurfaceMeshBoundaryAreasArrayPath = surface_mesh_boundary_areas_array_path
  filter.execute()
  return filter.ErrorCode

def find_directional_moduli(data_container_array, feature_phases_array_path = None, crystal_structures_array_path = None, crystal_compliances_array_path = None, avg_quats_array_path = None, directional_moduli_array_name = None, loading_direction = None, observer = None) -> int:
  """
  FindDirectionalModuli

  :param data_container_array | DataContainerArray
  :param feature_phases_array_path | DataArrayPath FeaturePhasesArrayPath
  :param crystal_structures_array_path | DataArrayPath CrystalStructuresArrayPath
  :param crystal_compliances_array_path | DataArrayPath CrystalCompliancesArrayPath
  :param avg_quats_array_path | DataArrayPath AvgQuatsArrayPath
  :param directional_moduli_array_name | QString DirectionalModuliArrayName
  :param loading_direction | FloatVec3Type LoadingDirection
  :param observer | Observer
  """

  filter = ucsbutilities.FindDirectionalModuli()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if feature_phases_array_path is not None:
    filter.FeaturePhasesArrayPath = feature_phases_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if crystal_compliances_array_path is not None:
    filter.CrystalCompliancesArrayPath = crystal_compliances_array_path
  if avg_quats_array_path is not None:
    filter.AvgQuatsArrayPath = avg_quats_array_path
  if directional_moduli_array_name is not None:
    filter.DirectionalModuliArrayName = directional_moduli_array_name
  if loading_direction is not None:
    filter.LoadingDirection = loading_direction
  filter.execute()
  return filter.ErrorCode

def find_modulus_mismatch(data_container_array, moduli_array_path = None, surface_mesh_face_labels_array_path = None, surface_mesh_delta_modulus_array_name = None, observer = None) -> int:
  """
  FindModulusMismatch

  :param data_container_array | DataContainerArray
  :param moduli_array_path | DataArrayPath ModuliArrayPath
  :param surface_mesh_face_labels_array_path | DataArrayPath SurfaceMeshFaceLabelsArrayPath
  :param surface_mesh_delta_modulus_array_name | QString SurfaceMeshDeltaModulusArrayName
  :param observer | Observer
  """

  filter = ucsbutilities.FindModulusMismatch()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if moduli_array_path is not None:
    filter.ModuliArrayPath = moduli_array_path
  if surface_mesh_face_labels_array_path is not None:
    filter.SurfaceMeshFaceLabelsArrayPath = surface_mesh_face_labels_array_path
  if surface_mesh_delta_modulus_array_name is not None:
    filter.SurfaceMeshDeltaModulusArrayName = surface_mesh_delta_modulus_array_name
  filter.execute()
  return filter.ErrorCode

def generate_misorientation_colors(data_container_array, reference_axis = None, reference_angle = None, cell_phases_array_path = None, quats_array_path = None, crystal_structures_array_path = None, good_voxels_array_path = None, misorientation_color_array_name = None, use_good_voxels = None, observer = None) -> int:
  """
  GenerateMisorientationColors

  :param data_container_array | DataContainerArray
  :param reference_axis | FloatVec3Type ReferenceAxis
  :param reference_angle | float ReferenceAngle
  :param cell_phases_array_path | DataArrayPath CellPhasesArrayPath
  :param quats_array_path | DataArrayPath QuatsArrayPath
  :param crystal_structures_array_path | DataArrayPath CrystalStructuresArrayPath
  :param good_voxels_array_path | DataArrayPath GoodVoxelsArrayPath
  :param misorientation_color_array_name | QString MisorientationColorArrayName
  :param use_good_voxels | bool UseGoodVoxels
  :param observer | Observer
  """

  filter = ucsbutilities.GenerateMisorientationColors()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if reference_axis is not None:
    filter.ReferenceAxis = reference_axis
  if reference_angle is not None:
    filter.ReferenceAngle = reference_angle
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  if quats_array_path is not None:
    filter.QuatsArrayPath = quats_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if good_voxels_array_path is not None:
    filter.GoodVoxelsArrayPath = good_voxels_array_path
  if misorientation_color_array_name is not None:
    filter.MisorientationColorArrayName = misorientation_color_array_name
  if use_good_voxels is not None:
    filter.UseGoodVoxels = use_good_voxels
  filter.execute()
  return filter.ErrorCode

def input_crystal_compliances(data_container_array, compliances = None, crystal_compliances_array_path = None, observer = None) -> int:
  """
  InputCrystalCompliances

  :param data_container_array | DataContainerArray
  :param compliances | FloatVec21_t Compliances
  :param crystal_compliances_array_path | DataArrayPath CrystalCompliancesArrayPath
  :param observer | Observer
  """

  filter = ucsbutilities.InputCrystalCompliances()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if compliances is not None:
    filter.Compliances = compliances
  if crystal_compliances_array_path is not None:
    filter.CrystalCompliancesArrayPath = crystal_compliances_array_path
  filter.execute()
  return filter.ErrorCode

